/*
 * This program is free software: you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or (at your
 * option) any later version.
 * 
 * This program is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License for
 * more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <https://www.gnu.org/licenses/>.
 */
package com.inteligr8.alfresco.activiti.api;

import java.io.File;

import javax.ws.rs.Consumes;
import javax.ws.rs.DELETE;
import javax.ws.rs.GET;
import javax.ws.rs.POST;
import javax.ws.rs.PUT;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;
import javax.ws.rs.Produces;
import javax.ws.rs.core.MediaType;

import com.inteligr8.alfresco.activiti.model.AppDefinitionPublishRepresentation;
import com.inteligr8.alfresco.activiti.model.AppDefinitionRepresentation;
import com.inteligr8.alfresco.activiti.model.AppDefinitionSaveRepresentation;
import com.inteligr8.alfresco.activiti.model.AppDefinitionUpdateResultRepresentation;

@Path("/api/enterprise/app-definitions")
public interface AppDefinitionsApi {

    @GET
    @Path("{modelId}")
    @Produces({ MediaType.APPLICATION_JSON })
    AppDefinitionRepresentation get(
    		@PathParam("modelId") Long appId);

    @PUT
    @Path("{modelId}")
    @Consumes({ MediaType.APPLICATION_JSON })
    @Produces({ MediaType.APPLICATION_JSON })
    AppDefinitionUpdateResultRepresentation update(
    		@PathParam("modelId") Long appId,
    		AppDefinitionSaveRepresentation updatedModel);

    @DELETE
    @Path("{appDefinitionId}")
    void delete(
    		@PathParam("appDefinitionId") Long appId);

    @GET
    @Path("{modelId}/export")
    @Produces({ MediaType.APPLICATION_JSON, "application/zip" })
    File export(
    		@PathParam("modelId") Long appId);

    @POST
    @Path("{modelId}/publish")
    @Consumes({ MediaType.APPLICATION_JSON })
    @Produces({ MediaType.APPLICATION_JSON })
    AppDefinitionUpdateResultRepresentation publish(
    		@PathParam("modelId") Long appId,
    		AppDefinitionPublishRepresentation publishModel);

}
